Hct

Struct Hct 

pub struct Hct { /* private fields */ }

Implementations

Source

impl Hct

pub const fn get_hue(&self) -> f64

A number, in degrees, representing ex. red, orange, yellow, etc. Ranges from 0 <= hue < 360

0 <= new_hue < 360; invalid values are corrected. After setting hue, the color is mapped from HCT to the more limited sRgb gamut for display. This will change its Argb/integer representation. If the HCT color is outside of the sRgb gamut, chroma will decrease until it is inside the gamut.

pub fn set_hue(&mut self, value: f64)

A number, in degrees, representing ex. red, orange, yellow, etc. Ranges from 0 <= hue < 360

0 <= new_hue < 360; invalid values are corrected. After setting hue, the color is mapped from HCT to the more limited sRgb gamut for display. This will change its Argb/integer representation. If the HCT color is outside of the sRgb gamut, chroma will decrease until it is inside the gamut.

pub const fn get_chroma(&self) -> f64

0 <= new_chroma <= ? After setting chroma, the color is mapped from HCT to the more limited sRgb gamut for display. This will change its Argb/integer representation. If the HCT color is outside of the sRgb gamut, chroma will decrease until it is inside the gamut.

pub fn set_chroma(&mut self, value: f64)

0 <= new_chroma <= ? After setting chroma, the color is mapped from HCT to the more limited sRgb gamut for display. This will change its Argb/integer representation. If the HCT color is outside of the sRgb gamut, chroma will decrease until it is inside the gamut.

pub const fn get_tone(&self) -> f64

Lightness. Ranges from 0 to 100.

0 <= new_tone <= 100; invalid values are corrected. After setting tone, the color is mapped from HCT to the more limited sRgb gamut for display. This will change its Argb/integer representation. If the HCT color is outside of the sRgb gamut, chroma will decrease until it is inside the gamut.

pub fn set_tone(&mut self, value: f64)

Lightness. Ranges from 0 to 100.

0 <= new_tone <= 100; invalid values are corrected. After setting tone, the color is mapped from HCT to the more limited sRgb gamut for display. This will change its Argb/integer representation. If the HCT color is outside of the sRgb gamut, chroma will decrease until it is inside the gamut.

pub fn new(argb: Argb) -> Self

pub fn from(hue: f64, chroma: f64, tone: f64) -> Self

0 <= hue < 360; invalid values are corrected. 0 <= chroma <= ?; Informally, colorfulness. The color returned may be lower than the requested chroma. Chroma has a different maximum for any given hue and tone. 0 <= tone <= 100; informally, lightness. Invalid values are corrected.

pub fn in_viewing_conditions(self, vc: &ViewingConditions) -> Self

Translate a color into different ViewingConditions.

Colors change appearance. They look different with lights on versus off, the same color, as in hex code, on white looks different when on black. This is called color relativity, most famously explicated by Josef Albers in Interaction of Color.

In color science, color appearance models can account for this and calculate the appearance of a color in different settings. HCT is based on CAM16, a color appearance model, and uses it to make these calculations.

See ViewingConditions for parameters affecting color appearance.