pub struct SchemeExpressive {
pub scheme: DynamicScheme,
}Expand description
A Dynamic Color theme that is intentionally detached from the input color.
Fields
scheme: DynamicSchemeImplementations
Sourceimpl SchemeExpressive
impl SchemeExpressive
Sourcepub const HUES: [f64; 9]
pub const HUES: [f64; 9]
Hues used at breakpoints such that designers can specify a hue rotation that occurs at a given break point.
Sourcepub const SECONDARY_ROTATIONS: [f64; 9]
pub const SECONDARY_ROTATIONS: [f64; 9]
Hue rotations of the Secondary TonalPalette, corresponding to the
breakpoints in hues.
Sourcepub const TERTIARY_ROTATIONS: [f64; 9]
pub const TERTIARY_ROTATIONS: [f64; 9]
Hue rotations of the Tertiary TonalPalette, corresponding to the
breakpoints in hues.
pub fn new( source_color_hct: Hct, is_dark: bool, contrast_level: Option<f64>, ) -> Self
pub fn palette(source_color_hct: &Hct, variant: &Palette) -> TonalPalette