HctSolver

Struct HctSolver 

pub struct HctSolver;

Implementations

Source

impl HctSolver

pub fn solve_to_argb(hue_degrees: f64, chroma: f64, lstar: f64) -> Argb

Finds an sRgb color with the given hue, chroma, and L*, if possible.

Returns a hexadecimal representing a sRgb color with its hue, chroma, and L* sufficiently close to hue_degrees, chroma, and lstar, respectively. If it is impossible to satisfy all three constraints, the hue and L* will be sufficiently close, and the chroma will be maximized.

pub fn solve_to_cam(hue_degrees: f64, chroma: f64, lstar: f64) -> Cam16

Finds a CAM16 object with the given hue, chroma, and L*, if possible.

Returns a CAM16 object representing a sRgb color with its hue, chroma, and L* sufficiently close to hue_degrees, chroma, and lstar, respectively. If it is impossible to satisfy all three constraints, the hue and L* will be sufficiently close, and the chroma will be maximized.