pub struct ThemeBuilder { /* private fields */ }Implementations
Sourceimpl ThemeBuilder
impl ThemeBuilder
Sourcepub const fn with_source(source: Argb) -> Self
pub const fn with_source(source: Argb) -> Self
Creates a theme builder with a custom source color.
Sourcepub const fn neutral(self, color: Argb) -> Self
pub const fn neutral(self, color: Argb) -> Self
Sets the neutral color, used for background and surfaces.
Sourcepub const fn neutral_variant(self, color: Argb) -> Self
pub const fn neutral_variant(self, color: Argb) -> Self
Sets the neutral variant color, used for for medium emphasis and variants.
Sourcepub fn custom_colors(self, custom_colors: Vec<CustomColor>) -> Self
pub fn custom_colors(self, custom_colors: Vec<CustomColor>) -> Self
Sets the custom colors, used as complementary tones.
Custom colors are also known as extended colors.
pub const fn color_match(self, enabled: bool) -> Self
pub fn build(self) -> Theme